@@ -178,7 +178,7 @@ class _GraphExpander:
         assert False, f'invalid percentage: {percent}'
 
     def _dot_node_lines(self, node, hilit):
-        uri = self._app.builder.get_target_uri(node.docname)
+        uri = self._app.builder.get_relative_uri(from_=self._docname, to=node.docname)
         node_id = '_'.join(node.path)
 
         border = 1
